@@ -11,25 +11,19 @@ function (formula, locations, data, model, debug.level = 1, set, degree = 0)
         stop("model should be of class variogramModel (use vgm)")
     fit.sills = rep(TRUE, length(model$model))
     fit.ranges = rep(FALSE, length(model$model))
-    .Call("gstat_init", as.integer(debug.level)
-    	, PACKAGE = "gstat"
-	)
+    .Call("gstat_init", as.integer(debug.level))
     ret = gstat.formula(formula, locations, data)
     ret$y <- residuals(lm(formula, data))
     .Call("gstat_new_data", as.double(ret$y), as.double(ret$locations),
 		as.double(ret$X), as.integer(1), double(0), as.integer(-1), 
 		as.integer(0), as.double(-1), as.integer(1), 
-		double(0), double(0), as.integer(degree)
-		, PACKAGE = "gstat"
-		)
+		double(0), double(0), as.integer(degree))
     load.variogram.model(model)
     if (!missing(set))
     	gstat.load.set(set)
     ret = .Call("gstat_fit_variogram", as.integer(5), 
-        as.integer(fit.sills), as.integer(fit.ranges)
-	, PACKAGE = "gstat"
-	)
-    .Call("gstat_exit", 0, PACKAGE = "gstat")
+        as.integer(fit.sills), as.integer(fit.ranges))
+    .Call("gstat_exit", 0) 
     model$psill = ret[[1]]
     model$range = ret[[2]]
     model
